@@ -605,8 +605,7 @@ class StylerTTK:
             shines through the corners using the `clam` theme. This is an unfortuate hack to make it look ok. Hopefully
             there will be a more permanent/better solution in the future.
         """
-        disabled_fg = self.theme.colors.inputfg
-        disabled_bg = (Colors.update_hsv(self.theme.colors.inputbg, vd=-0.2) if self.theme.type =='light' else
+        disabled_fg = (Colors.update_hsv(self.theme.colors.inputbg, vd=-0.2) if self.theme.type =='light' else
                        Colors.update_hsv(self.theme.colors.inputbg, vd=-0.3))
 
         if self.theme.type == 'dark':
@@ -635,22 +634,15 @@ class StylerTTK:
                     'padding': 5,
                     'arrowsize ': 14},
                 'map': {
-                    'background': [
-                        ('disabled', disabled_bg)],
                     'foreground': [
                         ('disabled', disabled_fg)],
-                    'fieldbackground': [
-                        ('disabled', disabled_bg)],
                     'bordercolor': [
-                        ('disabled', disabled_bg),
                         ('focus !disabled', self.theme.colors.primary),
                         ('hover !disabled', self.theme.colors.bg)],
                     'lightcolor': [
-                        ('disabled', disabled_bg),
                         ('focus !disabled', self.theme.colors.primary),
                         ('hover !disabled', self.theme.colors.primary)],
                     'darkcolor': [
-                        ('disabled', disabled_bg),
                         ('focus !disabled', self.theme.colors.primary),
                         ('hover !disabled', self.theme.colors.primary)],
                     'arrowcolor': [
@@ -663,16 +655,15 @@ class StylerTTK:
             self.settings.update({
                 f'{color}.TCombobox': {
                     'map': {
+                        'foreground': [
+                            ('disabled', disabled_fg)],
                         'bordercolor': [
-                            ('disabled', disabled_bg),
                             ('focus !disabled', self.theme.colors.get(color)),
                             ('hover !disabled', self.theme.colors.get(color))],
                         'lightcolor': [
-                            ('disabled', disabled_bg),
                             ('focus !disabled', self.theme.colors.get(color)),
                             ('pressed !disabled', self.theme.colors.get(color))],
                         'darkcolor': [
-                            ('disabled', disabled_bg),
                             ('focus !disabled', self.theme.colors.get(color)),
                             ('pressed !disabled', self.theme.colors.get(color))],
                         'arrowcolor': [
@@ -691,24 +682,38 @@ class StylerTTK:
 
             - Separator.separator: orient, background
         """
+        # create separator image
+        default_color = self.theme.colors.border if self.theme.type == 'light' else self.theme.colors.selectbg
+        im = Image.new('RGB', (1, 1))
+        draw = ImageDraw.Draw(im)
+        draw.rectangle([0, 0, 1, 1], fill=default_color)
+        self.theme_images['separator'] = ImageTk.PhotoImage(im)
+
         self.settings.update({
+            'Separator.separator': {
+                'element create': ('image', self.theme_images['separator'])},
             'Horizontal.TSeparator': {
-                'configure': {
-                    'background': (
-                        self.theme.colors.bg if self.theme.type == 'light' else self.theme.colors.primary)}},
+                'layout': [
+                    ('Separator.separator', {'sticky': 'nswe'})],
             'Vertical.TSeparator': {
-                'configure': {
-                    'background': (
-                        self.theme.colors.bg if self.theme.type == 'light' else self.theme.colors.primary)}}})
+                'layout': [
+                    ('Separator.separator', {'sticky': 'nswe'})]}}})
 
         for color in self.theme.colors:
+            im = Image.new('RGB', (1, 1))
+            draw = ImageDraw.Draw(im)
+            draw.rectangle([0, 0, 1, 1], fill=self.theme.colors.get(color))
+            self.theme_images[f'{color}_separator'] = ImageTk.PhotoImage(im)
+
             self.settings.update({
+                f'{color}.Separator.separator': {
+                    'element create': ('image', self.theme_images[f'{color}_separator'])},
                 f'{color}.Horizontal.TSeparator': {
-                    'configure': {
-                        'background': self.theme.colors.get(color)}},
+                    'layout': [
+                        (f'{color}.Separator.separator', {'sticky': 'nswe'})],
                 f'{color}.Vertical.TSeparator': {
-                    'configure': {
-                        'background': self.theme.colors.get(color)}}})
+                    'layout': [
+                        (f'{color}.Separator.separator', {'sticky': 'nswe'})]}}})
 
     def _style_progressbar(self):
         """
@@ -775,7 +780,7 @@ class StylerTTK:
         hover_vd = -0.1
 
         # create widget images
-        self.scale_images = {
+        self.theme_images = {
             'primary_disabled': self._create_slider_image(disabled_fg),
             'primary_regular': self._create_slider_image(self.theme.colors.primary),
             'primary_pressed': self._create_slider_image(
@@ -796,16 +801,16 @@ class StylerTTK:
                     ('Scale.focus', {'expand': '1', 'sticky': 'nswe', 'children': [
                         ('Vertical.Scale.track', {'sticky': 'ns'}),
                         ('Vertical.Scale.slider', {'side': 'top', 'sticky': ''})]})]},
-            'Scale.track': {'element create': ('image', self.scale_images['trough'])},
+            'Scale.track': {'element create': ('image', self.theme_images['trough'])},
             'Scale.slider': {
                 'element create':
-                    ('image', self.scale_images['primary_regular'],
-                     ('disabled', self.scale_images['primary_disabled']),
-                     ('pressed !disabled', self.scale_images['primary_pressed']),
-                     ('hover !disabled', self.scale_images['primary_hover']))}})
+                    ('image', self.theme_images['primary_regular'],
+                     ('disabled', self.theme_images['primary_disabled']),
+                     ('pressed !disabled', self.theme_images['primary_pressed']),
+                     ('hover !disabled', self.theme_images['primary_hover']))}})
 
         for color in self.theme.colors:
-            self.scale_images.update({
+            self.theme_images.update({
                 f'{color}_regular': self._create_slider_image(self.theme.colors.get(color)),
                 f'{color}_pressed': self._create_slider_image(
                     Colors.update_hsv(self.theme.colors.get(color), vd=pressed_vd)),
@@ -829,15 +834,15 @@ class StylerTTK:
                                 (f'{color}.Vertical.Scale.slider', {'side': 'top', 'sticky': ''})]})]},
                 f'{color}.Vertical.Scale.slider': {
                     'element create':
-                        ('image', self.scale_images[f'{color}_regular'],
-                         ('pressed', self.scale_images[f'{color}_pressed']),
-                         ('hover', self.scale_images[f'{color}_hover']))},
+                        ('image', self.theme_images[f'{color}_regular'],
+                         ('pressed', self.theme_images[f'{color}_pressed']),
+                         ('hover', self.theme_images[f'{color}_hover']))},
                 f'{color}.Horizontal.Scale.slider': {
                     'element create':
-                        ('image', self.scale_images[f'{color}_regular'],
-                         ('disabled', self.scale_images['primary_disabled']),
-                         ('pressed', self.scale_images[f'{color}_pressed']),
-                         ('hover', self.scale_images[f'{color}_hover']))}})
+                        ('image', self.theme_images[f'{color}_regular'],
+                         ('disabled', self.theme_images['primary_disabled']),
+                         ('pressed', self.theme_images[f'{color}_pressed']),
+                         ('hover', self.theme_images[f'{color}_hover']))}})
 
     def _style_scrollbar(self):
         """
@@ -885,8 +890,7 @@ class StylerTTK:
             - spinbox.padding: padding, relief, shiftrelief
             - spinbox.textarea: font, width
         """
-        disabled_fg = self.theme.colors.inputfg
-        disabled_bg = (Colors.update_hsv(self.theme.colors.inputbg, vd=-0.2) if self.theme.type =='light' else
+        disabled_fg = (Colors.update_hsv(self.theme.colors.inputbg, vd=-0.2) if self.theme.type =='light' else
                        Colors.update_hsv(self.theme.colors.inputbg, vd=-0.3))
 
         if self.theme.type == 'dark':
@@ -917,22 +921,15 @@ class StylerTTK:
                     'padding': (10, 5)
                 },
                 'map': {
-                    'fieldbackground': [
-                        ('disabled', disabled_bg)],
-                    'background': [
-                        ('disabled', disabled_bg)],
                     'foreground': [
                         ('disabled', disabled_fg)],
                     'bordercolor': [
-                        ('disabled', disabled_bg),
                         ('focus !disabled', self.theme.colors.primary),
                         ('hover !disabled', self.theme.colors.bg)],
                     'lightcolor': [
-                        ('disabled', disabled_bg),
                         ('focus !disabled', self.theme.colors.primary),
                         ('hover !disabled', self.theme.colors.primary)],
                     'darkcolor': [
-                        ('disabled', disabled_bg),
                         ('focus !disabled', self.theme.colors.primary),
                         ('hover !disabled', self.theme.colors.primary)],
                     'arrowcolor': [
@@ -945,8 +942,9 @@ class StylerTTK:
             self.settings.update({
                 f'{color}.TSpinbox': {
                     'map': {
+                        'foreground': [
+                            ('disabled', disabled_fg)],
                         'bordercolor': [
-                            ('disabled', disabled_bg),
                             ('focus !disabled', self.theme.colors.get(color)),
                             ('hover !disabled', self.theme.colors.get(color))],
                         'arrowcolor': [
@@ -954,10 +952,8 @@ class StylerTTK:
                             ('pressed !disabled', self.theme.colors.get(color)),
                             ('hover !disabled', self.theme.colors.inputfg)],
                         'lightcolor': [
-                            ('disabled', disabled_bg),
                             ('focus !disabled', self.theme.colors.get(color))],
                         'darkcolor': [
-                            ('disabled', disabled_bg),
                             ('focus !disabled', self.theme.colors.get(color))]}}})
 
     def _style_treeview(self):
@@ -986,8 +982,7 @@ class StylerTTK:
                 - Treeheading.image: image, stipple, background
                 - Treeheading.text: text, font, foreground, underline, width, anchor, justify, wraplength, embossed
         """
-        disabled_fg = self.theme.colors.inputfg
-        disabled_bg = (Colors.update_hsv(self.theme.colors.inputbg, vd=-0.2) if self.theme.type =='light' else
+        disabled_fg = (Colors.update_hsv(self.theme.colors.inputbg, vd=-0.2) if self.theme.type =='light' else
                        Colors.update_hsv(self.theme.colors.inputbg, vd=-0.3))
 
         self.settings.update({
@@ -1007,7 +1002,6 @@ class StylerTTK:
                 },
                 'map': {
                     'background': [
-                        ('disabled', disabled_bg),
                         ('selected', self.theme.colors.selectbg)],
                     'foreground': [
                         ('disabled', disabled_fg),
@@ -1026,7 +1020,10 @@ class StylerTTK:
                     'configure': {
                         'background': self.theme.colors.get(color)},
                     'map': {
-                        'bordercolor': [('focus', self.theme.colors.get(color))]}}})
+                        'foreground': [
+                            ('disabled', disabled_fg)],
+                        'bordercolor': [
+                            ('focus !disabled', self.theme.colors.get(color))]}}})
 
     def _style_frame(self):
         """
@@ -1144,8 +1141,7 @@ class StylerTTK:
                 embossed, image, stipple, background
         """
         # disabled settings
-        disabled_fg = self.theme.colors.inputfg
-        disabled_bg = (Colors.update_hsv(self.theme.colors.inputbg, vd=-0.2) if self.theme.type =='light' else
+        disabled_fg = (Colors.update_hsv(self.theme.colors.inputbg, vd=-0.2) if self.theme.type =='light' else
                        Colors.update_hsv(self.theme.colors.inputbg, vd=-0.3))
 
 
@@ -1171,19 +1167,16 @@ class StylerTTK:
                         ('pressed !disabled', self.theme.colors.selectfg),
                         ('hover !disabled', self.theme.colors.selectfg)],
                     'background': [
-                        ('disabled', disabled_bg),
                         ('pressed !disabled', Colors.update_hsv(self.theme.colors.primary, vd=pressed_vd)),
                         ('hover !disabled', self.theme.colors.primary)],
                     'bordercolor': [
-                        ('disabled', disabled_bg),
+                        ('disabled', disabled_fg),
                         ('pressed !disabled', Colors.update_hsv(self.theme.colors.primary, vd=pressed_vd)),
                         ('hover !disabled', self.theme.colors.primary)],
                     'darkcolor': [
-                        ('disabled', disabled_bg),
                         ('pressed !disabled', Colors.update_hsv(self.theme.colors.primary, vd=pressed_vd)),
                         ('hover !disabled', self.theme.colors.primary)],
                     'lightcolor': [
-                        ('disabled', disabled_bg),
                         ('pressed !disabled', Colors.update_hsv(self.theme.colors.primary, vd=pressed_vd)),
                         ('hover !disabled', self.theme.colors.primary)]}}})
 
@@ -1206,19 +1199,16 @@ class StylerTTK:
                             ('pressed !disabled', self.theme.colors.selectfg),
                             ('hover !disabled', self.theme.colors.selectfg)],
                         'background': [
-                            ('disabled', disabled_bg),
                             ('pressed !disabled', Colors.update_hsv(self.theme.colors.get(color), vd=pressed_vd)),
                             ('hover !disabled', self.theme.colors.get(color))],
                         'bordercolor': [
-                            ('disabled', disabled_bg),
+                            ('disabled', disabled_fg),
                             ('pressed !disabled', Colors.update_hsv(self.theme.colors.get(color), vd=pressed_vd)),
                             ('hover !disabled', self.theme.colors.get(color))],
                         'darkcolor': [
-                            ('disabled', disabled_bg),
                             ('pressed !disabled', Colors.update_hsv(self.theme.colors.get(color), vd=pressed_vd)),
                             ('hover !disabled', self.theme.colors.get(color))],
                         'lightcolor': [
-                            ('disabled', disabled_bg),
                             ('pressed !disabled', Colors.update_hsv(self.theme.colors.get(color), vd=pressed_vd)),
                             ('hover !disabled', self.theme.colors.get(color))]}}})
 
@@ -1232,8 +1222,7 @@ class StylerTTK:
             - Entry.padding: padding, relief, shiftrelief
             - Entry.textarea: font, width
         """
-        disabled_fg = self.theme.colors.inputfg
-        disabled_bg = (Colors.update_hsv(self.theme.colors.inputbg, vd=-0.2) if self.theme.type =='light' else
+        disabled_fg = (Colors.update_hsv(self.theme.colors.inputbg, vd=-0.2) if self.theme.type =='light' else
                        Colors.update_hsv(self.theme.colors.inputbg, vd=-0.3))
 
         if self.theme.type == 'dark':
@@ -1250,31 +1239,26 @@ class StylerTTK:
                     'borderwidth': 0,  # only applies to border on darktheme
                     'padding': 5},
                 'map': {
-                    'fieldbackground': [('disabled', disabled_bg)],
                     'foreground': [('disabled', disabled_fg)],
                     'bordercolor': [
-                        ('disabled', disabled_bg),
                         ('focus !disabled', self.theme.colors.primary),
                         ('hover !disabled', self.theme.colors.primary)],
                     'lightcolor': [
-                        ('disabled', disabled_bg),
                         ('focus !disabled', self.theme.colors.primary)],
                     'darkcolor': [
-                        ('disabled', disabled_bg),
                         ('focus !disabled', self.theme.colors.primary)]}}})
 
         for color in self.theme.colors:
             self.settings.update({
                 f'{color}.TEntry': {
                     'map': {
+                        'foreground': [
+                            ('disabled', disabled_fg)],
                         'bordercolor': [
-                            ('disabled', disabled_bg),
                             ('focus !disabled', self.theme.colors.get(color))],
                         'lightcolor': [
-                            ('disabled', disabled_bg),
                             ('focus !disabled', self.theme.colors.get(color))],
                         'darkcolor': [
-                            ('disabled', disabled_bg),
                             ('focus !disabled', self.theme.colors.get(color))]}}})
 
     def _style_radiobutton(self):
@@ -1564,8 +1548,7 @@ class StylerTTK:
             - Menubutton.label:
         """
         # disabled settings
-        disabled_fg = self.theme.colors.inputfg
-        disabled_bg = (Colors.update_hsv(self.theme.colors.inputbg, vd=-0.2) if self.theme.type =='light' else
+        disabled_fg = (Colors.update_hsv(self.theme.colors.inputbg, vd=-0.2) if self.theme.type =='light' else
                        Colors.update_hsv(self.theme.colors.inputbg, vd=-0.3))
 
         # pressed and hover settings
@@ -1593,19 +1576,16 @@ class StylerTTK:
                         ('pressed !disabled', self.theme.colors.selectfg),
                         ('hover !disabled', self.theme.colors.selectfg)],
                     'background': [
-                        ('disabled', disabled_bg),
                         ('pressed !disabled', Colors.update_hsv(self.theme.colors.primary, vd=pressed_vd)),
                         ('hover !disabled', Colors.update_hsv(self.theme.colors.primary, vd=hover_vd))],
                     'bordercolor': [
-                        ('disabled', disabled_bg),
+                        ('disabled', disabled_fg),
                         ('pressed !disabled', Colors.update_hsv(self.theme.colors.primary, vd=pressed_vd)),
                         ('hover !disabled', Colors.update_hsv(self.theme.colors.primary, vd=hover_vd))],
                     'darkcolor': [
-                        ('disabled', disabled_bg),
                         ('pressed !disabled', Colors.update_hsv(self.theme.colors.primary, vd=pressed_vd)),
                         ('hover !disabled', Colors.update_hsv(self.theme.colors.primary, vd=hover_vd))],
                     'lightcolor': [
-                        ('disabled', disabled_bg),
                         ('pressed !disabled', Colors.update_hsv(self.theme.colors.primary, vd=pressed_vd)),
                         ('hover !disabled', Colors.update_hsv(self.theme.colors.primary, vd=hover_vd))],
                     'arrowcolor': [
@@ -1634,19 +1614,16 @@ class StylerTTK:
                             ('pressed !disabled', self.theme.colors.selectfg),
                             ('hover !disabled', self.theme.colors.selectfg)],
                         'background': [
-                            ('disabled', disabled_bg),
                             ('pressed !disabled', Colors.update_hsv(self.theme.colors.get(color), vd=pressed_vd)),
                             ('hover !disabled', Colors.update_hsv(self.theme.colors.get(color), vd=hover_vd))],
                         'bordercolor': [
-                            ('disabled', disabled_bg),
+                            ('disabled', disabled_fg),
                             ('pressed !disabled', Colors.update_hsv(self.theme.colors.get(color), vd=pressed_vd)),
                             ('hover !disabled', Colors.update_hsv(self.theme.colors.get(color), vd=hover_vd))],
                         'darkcolor': [
-                            ('disabled', disabled_bg),
                             ('pressed !disabled', Colors.update_hsv(self.theme.colors.get(color), vd=pressed_vd)),
                             ('hover !disabled', Colors.update_hsv(self.theme.colors.get(color), vd=hover_vd))],
                         'lightcolor': [
-                            ('disabled', disabled_bg),
                             ('pressed !disabled', Colors.update_hsv(self.theme.colors.get(color), vd=pressed_vd)),
                             ('hover !disabled', Colors.update_hsv(self.theme.colors.get(color), vd=hover_vd))],
                         'arrowcolor': [
